@@ -25,11 +25,12 @@
 import os
 import subprocess
 from osgeo import gdal, gdalconst
-from .filesystem import juststem, tempfilename, listify
+from .filesystem import juststem, justpath, tempfilename, listify
+from .filesystem import now, total_seconds_from, forceext
 from .module_ogr import SameSpatialRef, GetSpatialRef
 from .module_meta import GetNoData, GDALFixNoData
 from .module_Numpy2GTiff import CalculateStats
-from .module_s3 import *
+from .module_s3 import copy, isfile, move, remove
 from .gdal_translate import dtypeOf
 from .module_log import Logger
 
@@ -118,7 +119,7 @@ def gdalwarp(filelist,
         kwargs["yRes"] = abs(pixelsize[1])
 
     if len(filelist) == 1 and SameSpatialRef(filelist_tmp[0], dstSRS):
-        Logger.debug(f"Avoid reprojecting {filelist[0]}")
+        Logger.debug("Avoid reprojecting %s", filelist[0])
     elif dstSRS:
         kwargs["dstSRS"] = GetSpatialRef(dstSRS)
 
@@ -136,31 +137,43 @@ def gdalwarp(filelist,
     try:
         gdal.UseExceptions()
         gdal.PushErrorHandler('CPLQuietErrorHandler')
+        print("[GDALWARP] out files:", filetmp)
+        print("[GDALWARP] warping files:", filelist_tmp)
+        print("[GDALWARP] dstSRS:", dstSRS)
         gdal.Warp(filetmp, filelist_tmp, **kwargs)
+        print("[GDALWARP] gdalwarp completed successfully")
+        print("[GDALWARP] but fileprj:", os.path.exists(forceext(filetmp, "prj")))
     except Exception as ex:
-        Logger.error(ex)
+        print("[GDALWARP]",ex)
     finally:
         gdal.PopErrorHandler()
 
     # patch notdata value
     if dstNodata is not None and GetNoData(filetmp) != dstNodata:
-        Logger.debug(f"gdalwarp: fixing nodata value to {dstNodata}")
-        GDALFixNoData(filetmp, format=format, nodata = dstNodata)
-    
+        Logger.debug("gdalwarp: fixing nodata value to %s", dstNodata)
+        GDALFixNoData(filetmp, format=format, nodata=dstNodata)
+        print("[GDALFixNoData] but fileprj:", os.path.exists(forceext(filetmp, "prj")))
+
     if stats and isfile(filetmp):
-        #os.system(f'gdalinfo -stats "{filetmp}"')
-        subprocess.run(["gdalinfo", "-stats", filetmp], shell=False, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
-        move(f"{filetmp}.aux.xml", f"{fileout}.aux.xml")
+        #subprocess.run(["gdalinfo", "-stats", filetmp], shell=False, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        #move(f"{filetmp}.aux.xml", f"{fileout}.aux.xml")
+        # try:
+        #     CalculateStats(filetmp)
+        # except Exception as ex:
+        #     print(f"[GDALWARP]: error calculating stats: {ex}")
+        pass
 
     # moving the filetmp to fileout
+    print("[GDALWARP] moved filetmp to fileout:", os.path.exists(forceext(filetmp,"prj")))
     move(filetmp, fileout)
+    print("[GDALWARP] moved filetmp to fileout:", os.path.exists(forceext(fileout,"prj")))
 
-    Logger.debug(
-        f"gdalwarp: converted to {fileout} in {total_seconds_from(t0)} s.")
+    Logger.debug("gdalwarp: converted to %s in %.2fs.",
+                 fileout, total_seconds_from(t0))
 
     # clean the cutline file
     remove(cutline_tmp)
 
-    Logger.debug(f"gdalwarp: completed in {total_seconds_from(t0)} s.")
+    Logger.debug("gdalwarp: completed in %.2fs.", total_seconds_from(t0))
     # ----------------------------------------------------------------------
     return fileout
